@@ -13,7 +13,7 @@ package Printer::ESCPOS::Profiles::Generic;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -480,7 +480,7 @@ Printer::ESCPOS::Profiles::Generic - Generic Profile for Printers for L<Printer:
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 METHODS
 
@@ -519,13 +519,13 @@ moves the cursor to next horizontal tab position like a "\t". This command is ig
 
 This
 
-    $device->printer->write("blah blah");
+    $device->printer->text("blah blah");
     $device->printer->tab();
-    $device->printer->write("blah2 blah2");
+    $device->printer->text("blah2 blah2");
 
 is same as this
 
-    $device->printer->write("blah blah\tblah2 blah2");
+    $device->printer->text("blah blah\tblah2 blah2");
 
 =head2 lf
 
@@ -533,13 +533,13 @@ line feed. Moves to the next line. You can substitute this method with {"\n"} in
 
 This
 
-    $device->printer->write("blah blah");
+    $device->printer->text("blah blah");
     $device->printer->lf();
-    $device->printer->write("blah2 blah2");
+    $device->printer->text("blah2 blah2");
 
 is same as this
 
-    $device->printer->write("blah blah\nblah2 blah2");
+    $device->printer->text("blah blah\nblah2 blah2");
 
 =head2 ff
 
@@ -560,47 +560,47 @@ Cancel (delete) page data in page mode
 Set Font style, you can pass *a*, *b* or *c*. Many printers don't support style *c* and only have two supported styles.
 
     $device->printer->font('a');
-    $device->printer->write('Writing in Font A');
+    $device->printer->text('Writing in Font A');
     $device->printer->font('b');
-    $device->printer->write('Writing in Font B');
+    $device->printer->text('Writing in Font B');
 
 =head2 bold 
 
 Set bold mode *0* for off and *1* for on. Also called emphasized mode in some printer manuals 
 
     $device->printer->bold(1);
-    $device->printer->write("This is Bold Text\n");
+    $device->printer->text("This is Bold Text\n");
     $device->printer->bold(0);
-    $device->printer->write("This is not Bold Text\n");
+    $device->printer->text("This is not Bold Text\n");
 
 =head2 doubleStrike 
 
 Set double-strike mode *0* for off and *1* for on
 
     $device->printer->doubleStrike(1);
-    $device->printer->write("This is Double Striked Text\n");
+    $device->printer->text("This is Double Striked Text\n");
     $device->printer->doubleStrike(0);
-    $device->printer->write("This is not Double Striked  Text\n");
+    $device->printer->text("This is not Double Striked  Text\n");
 
 =head2 underline
 
 set underline, *0* for off, *1* for on and *2* for double thickness 
 
     $device->printer->underline(1);
-    $device->printer->write("This is Underlined Text\n");
+    $device->printer->text("This is Underlined Text\n");
     $device->printer->underline(2);
-    $device->printer->write("This is Underlined Text with thicker underline\n");
+    $device->printer->text("This is Underlined Text with thicker underline\n");
     $device->printer->underline(0);
-    $device->printer->write("This is not Underlined Text\n");
+    $device->printer->text("This is not Underlined Text\n");
 
 =head2 invert
 
 Reverse white/black printing mode pass *0* for off and *1* for on
 
     $device->printer->invert(1);
-    $device->printer->write("This is Inverted Text\n");
+    $device->printer->text("This is Inverted Text\n");
     $device->printer->invert(0);
-    $device->printer->write("This is not Inverted Text\n");
+    $device->printer->text("This is not Inverted Text\n");
 
 =head2 color
 
@@ -608,10 +608,10 @@ Most thermal printers support just one color, black. Some ESCPOS printers(especi
 
     $device->printer->lf();
     $device->printer->color(0); #black
-    $device->printer->write("black"); 
+    $device->printer->text("black"); 
     $device->printer->lf();
     $device->printer->color(1); #red
-    $device->printer->write("Red"); 
+    $device->printer->text("Red"); 
     $device->printer->print();
 
 =head2 justify 
@@ -619,25 +619,25 @@ Most thermal printers support just one color, black. Some ESCPOS printers(especi
 Set Justification. Options *left*, *right* and *center*
 
     $device->printer->justify( 'right' );
-    $device->printer->write("This is right justified"); 
+    $device->printer->text("This is right justified"); 
 
 =head2 upsideDown
 
 Sets Upside Down Printing on/off (pass *0* or *1*)
 
     $device->printer->upsideDownPrinting(1);
-    $device->printer->write("This text is upside down"); 
+    $device->printer->text("This text is upside down"); 
 
 =head2 fontHeight 
 
 Set font height. Only supports *0* or *1* for printmode set to 1, supports values *0*, *1*, *2*, *3*, *4*, *5*, *6* and *7* for non-printmode state (default) 
 
     $device->printer->fontHeight(1);
-    $device->printer->write("double height\n");
+    $device->printer->text("double height\n");
     $device->printer->fontHeight(2);
-    $device->printer->write("triple height\n");
+    $device->printer->text("triple height\n");
     $device->printer->fontHeight(3);
-    $device->printer->write("quadruple height\n");
+    $device->printer->text("quadruple height\n");
     . . .
 
 =head2 fontWidth 
@@ -645,11 +645,11 @@ Set font height. Only supports *0* or *1* for printmode set to 1, supports value
 Set font width. Only supports *0* or *1* for printmode set to 1, supports values *0*, *1*, *2*, *3*, *4*, *5*, *6* and *7* for non-printmode state (default) 
 
     $device->printer->fontWidth(1);
-    $device->printer->write("double width\n");
+    $device->printer->text("double width\n");
     $device->printer->fontWidth(2);
-    $device->printer->write("triple width\n");
+    $device->printer->text("triple width\n");
     $device->printer->fontWidth(3);
-    $device->printer->write("quadruple width\n");
+    $device->printer->text("quadruple width\n");
     . . .
 
 =head2 charSpacing
@@ -657,7 +657,7 @@ Set font width. Only supports *0* or *1* for printmode set to 1, supports values
 Sets character spacing takes a value between 0 and 255
 
     $device->printer->charSpacing(5);
-    $device->printer->write("Blah Blah Blah\n");
+    $device->printer->text("Blah Blah Blah\n");
     $device->printer->print();
 
 =head2 lineSpacing 
